bayespy.inference.vmp.nodes.gaussian.GaussianWishartMoments.get_converter
=========================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianWishartMoments.get_converter